@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
 
 1;
 
@@ -166,6 +166,14 @@ Add_site command examples:
     sparrow project foo add_site tomcat_app  127.0.0.1:8080/app/
     sparrow project foo add_site mongodb_http mongo.host:28017
 
+To get linked site information say this:
+
+I<sparrow project $project_name site_info $site_name>
+
+For example:
+
+    sparrow project foo site_info nginx_proxy
+
 
 =head2 run swat tests
 
@@ -198,6 +206,14 @@ This command setups L<swat ini file|https://github.com/melezhik/swat#swat-ini-fi
 
 More information on swat ini files syntax could be found here - L<https://github.com/melezhik/swat#swat-ini-files|https://github.com/melezhik/swat#swat-ini-files>
 
+To get site's swat settings say this:
+
+I<sparrow project $project_name site_info $site_name --swat>
+
+For example:
+
+    sparrow project foo site_info nginx_proxy --swat
+
 
 =head2 run swat tests remotely
 
